@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -56,6 +56,7 @@
 #define CODECHAL_ENCODE_VP9_PIC_STATE_BUFFER_SIZE_PER_PASS      192 // 42 DWORDs for Pic State one uint32_t for BB End + 5 uint32_tS reserved to make it aligned for kernel read
 #define CODECHAL_ENCODE_VP9_MIN_TILE_SIZE_WIDTH                 256
 #define CODECHAL_ENCODE_VP9_MIN_TILE_SIZE_HEIGHT                128
+#define CODECHAL_ENCODE_VP9_NUM_MAX_L0_REF                      3
 #define CODECHAL_ENCODE_VP9_HUC_SUPERFRAME_PASS                 2
 #define CODECHAL_ENCODE_VP9_REF_SEGMENT_DISABLED                0xFF
 #define CODECHAL_ENCODE_VP9_BRC_MAX_NUM_OF_PASSES               4
@@ -71,10 +72,6 @@
 #define CODECHAL_VDENC_VP9_BRC_HUC_STATUS_MEMORY_ACCESS_ERROR_MASK       (1 << 26)
 #define CODECHAL_VDENC_VP9_BRC_HUC_STATUS_DMEM_ERROR_MASK                (1 << 24)
 
-#define __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_ENABLE_BRC_DLL                 5158
-#define __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_BRC_DLL_PATH                   5159
-#define __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_ENABLE_BRC_DLL_CUSTOMPATH      5160
-
 #define VP9SWBRCLIB  "VP9BRCDLL.dll"
 
 typedef struct _HUC_AUX_BUFFER
